@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::FormatAssertion;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Format-Assertion vocabulary
 
-our $VERSION = '0.559';
+our $VERSION = '0.560';
 
 use 5.020;
 use Moo;
@@ -164,7 +164,7 @@ sub _eval_keyword_format ($self, $data, $schema, $state) {
     }
   }
   catch ($e) {
-    return E($state, 'cannot validate format "%s": %s', $schema->{format}, $e);
+    abort($state, 'EXCEPTION: cannot validate format "%s": %s', $schema->{format}, $e);
   }
 
   # first check the subrefs from JSON::Schema::Modern->new(format_evaluations => { ... })
@@ -198,7 +198,7 @@ JSON::Schema::Modern::Vocabulary::FormatAssertion - Implementation of the JSON S
 
 =head1 VERSION
 
-version 0.559
+version 0.560
 
 =head1 DESCRIPTION
 
